package com.ruoyi.system.mapper;


import com.ruoyi.system.entity.TableInfo;
import com.ruoyi.system.entity.vo.TableInfoVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

public interface TableInfoMapper {

    /**
     * 查询数据库中的表信息
     */
    List<TableInfoVO> tableInfoList(@Param("databaseName") String databaseName, @Param("map") Map<String, Object> map);


    /**
     * 获取当前库中所有表信息
     */
    List<TableInfoVO> sqlServerTableInfoList(@Param("databaseName") String databaseName, @Param("map") Map<String, Object> map);

    /**
     * 库中所有表信息
     */
    List<TableInfoVO> dmTableInfoList(@Param("databaseName") String databaseName, @Param("map") Map<String, Object> map);


    /**
     * 获取表结构
     */
    List<TableInfo> mysqlTableFieldInfo(@Param("dataBaseName") String dataBaseName, @Param("tableName") String tableName);

    /**
     * 查询表结构
     */
    List<TableInfo> sqlserverTableFieldInfo(@Param("tableName") String tableName);

    /**
     * 查询表结构
     */
    List<TableInfo> dmTableFieldInfo(@Param("dataBaseName") String dataBaseName, @Param("tableName") String tableName);


}
